@@ -1,10 +1,11 @@
 # Gitless - a version control system built on top of Git.
-# Copyright (c) 2013  Santiago Perez De Rosso.
-# Licensed under GNU GPL, version 2.
+# Licensed under GNU GPL v2.
 
 """gl branch - Create, edit, delete or switch branches."""
 
 
+from clint.textui import colored
+
 from gitless.core import branch as branch_lib
 from gitless.core import sync as sync_lib
 
@@ -27,6 +28,9 @@ def parser(subparsers):
   branch_parser.add_argument(
       '-su', '--set-upstream', help='set the upstream branch',
       dest='upstream_b')
+  branch_parser.add_argument(
+      '-uu', '--unset-upstream', help='unset the upstream branch',
+      action='store_true')
   branch_parser.set_defaults(func=main)
 
 
@@ -34,9 +38,10 @@ def main(args):
   ret = True
   if args.branch:
     b_st = branch_lib.status(args.branch)
-    if b_st.exists and b_st.is_current:
+    if b_st and b_st.is_current:
       pprint.err(
-          'You are already in branch %s. No need to switch.' % args.branch)
+          'You are already in branch {0}. No need to switch.'.format(
+              colored.green(args.branch)))
       pprint.err_exp('to list existing branches do gl branch')
       return False
 
@@ -51,15 +56,17 @@ def main(args):
           '-- this will be implemented in the future)')
       return False
 
-    if not b_st.exists and not _do_create(args.branch, args.divergent_point):
+    if not b_st and not _do_create(args.branch, args.divergent_point):
       return False
 
     branch_lib.switch(args.branch)
-    pprint.msg('Switched to branch %s' % args.branch)
+    pprint.msg('Switched to branch {0}'.format(colored.green(args.branch)))
   elif args.delete_b:
     ret = _do_delete(args.delete_b)
   elif args.upstream_b:
     ret = _do_set_upstream(args.upstream_b)
+  elif args.unset_upstream:
+    ret = _do_unset_upstream()
   else:
     _do_list()
 
@@ -77,9 +84,9 @@ def _do_create(branch_name, divergent_point):
     pprint.msg('Invalid divergent point {0}'.format(divergent_point))
     errors_found = True
   elif ret == branch_lib.SUCCESS:
-    pprint.msg('Created new branch %s' % branch_name)
+    pprint.msg('Created new branch {0}'.format(branch_name))
   else:
-    raise Exception('Unrecognized ret code %s' % ret)
+    raise Exception('Unrecognized ret code {0}'.format(ret))
   return not errors_found
 
 
@@ -96,8 +103,9 @@ def _do_list():
     upstream_str = ''
     if upstream:
       np_str = ' --not present in remote yet' if not upstream_exists else ''
-      upstream_str = '(upstream is %s%s)' % (upstream, np_str)
-    pprint.item('%s %s %s' % (current_str, name, upstream_str))
+      upstream_str = '(upstream is {0}{1})'.format(upstream, np_str)
+    color = colored.green if is_current else colored.yellow
+    pprint.item('{0} {1} {2}'.format(current_str, color(name), upstream_str))
 
 
 def _do_delete(delete_b):
@@ -105,21 +113,22 @@ def _do_delete(delete_b):
 
   for b in delete_b:
     b_st = branch_lib.status(b)
-    if not b_st.exists:
-      pprint.err('Can\'t remove non-existent branch %s' % b)
+    cb = colored.green(b)
+    if not b_st:
+      pprint.err('Can\'t remove non-existent branch {0}'.format(cb))
       pprint.err_exp('do gl branch to list existing branches')
       errors_found = True
-    elif b_st.exists and b_st.is_current:
-      pprint.err('Can\'t remove current branch %s' % b)
+    elif b_st and b_st.is_current:
+      pprint.err('Can\'t remove current branch {0}'.format(cb))
       pprint.err_exp(
           'do gl branch <b> to create or switch to another branch b and then '
-          'gl branch -d %s to remove branch %s' % (b, b))
+          'gl branch -d {0} to remove branch {0}'.format(cb))
       errors_found = True
-    elif not pprint.conf_dialog('Branch %s will be removed' % b):
-      pprint.msg('Aborted: removal of branch %s' % b)
+    elif not pprint.conf_dialog('Branch {0} will be removed'.format(cb)):
+      pprint.msg('Aborted: removal of branch {0}'.format(cb))
     else:
       branch_lib.delete(b)
-      pprint.msg('Branch %s removed successfully' % b)
+      pprint.msg('Branch {0} removed successfully'.format(cb))
 
   return not errors_found
 
@@ -135,14 +144,34 @@ def _do_set_upstream(upstream):
   errors_found = False
   upstream_remote, upstream_branch = upstream.split('/')
   if ret is branch_lib.REMOTE_NOT_FOUND:
-    pprint.err('Remote %s not found' % upstream_remote)
+    pprint.err('Remote {0} not found'.format(upstream_remote))
     pprint.err_exp('do gl remote to list all existing remotes')
     pprint.err_exp(
-        'do gl remote %s <r_url> to add a new remote %s mapping to '
-        'r_url' % (upstream_remote, upstream_remote))
+        'do gl remote {0} <r_url> to add a new remote {0} mapping to '
+        'r_url'.format(upstream_remote))
     errors_found = True
   elif ret is branch_lib.SUCCESS:
-    pprint.msg('Current branch %s set to track %s/%s' % (
-        branch_lib.current(), upstream_remote, upstream_branch))
+    pprint.msg(
+        'Current branch {0} set to track {1}/{2}'.format(
+            colored.green(branch_lib.current()), upstream_remote,
+            upstream_branch))
+
+  return not errors_found
+
+
+def _do_unset_upstream():
+  ret = branch_lib.unset_upstream()
+
+  errors_found = False
+  if ret is branch_lib.UPSTREAM_NOT_SET:
+    pprint.err('Current branch has no upstream set')
+    pprint.err_exp(
+        'do gl branch to list all existing branches -- if a branch has an '
+        'upstream set it will be shown')
+    pprint.err_exp(
+      'do gl branch -su <upstream> to set an upstream for the current branch')
+    errors_found = True
+  elif ret is branch_lib.SUCCESS:
+    pprint.msg('Upstream unset for current branch')
 
   return not errors_found
